silvio.extensions.records package
=================================

.. automodule:: silvio.extensions.records
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    silvio.extensions.records.gene

Submodules
----------

silvio.extensions.records.growth\_record module
-----------------------------------------------

.. automodule:: silvio.extensions.records.growth_record
    :members:
    :undoc-members:
    :show-inheritance:


